@@ -1036,6 +1036,32 @@ static void action_set_sensitive(GigoloWindow *window, const gchar *name, gboole
 }
 
 
+static void gigolo_window_systray_notify_cb(GtkStatusIcon *sicon, GParamSpec *pspec, GtkWindow *window)
+{
+	const gchar *name;
+	GValue *value;
+
+	/* nothing to do if the main window is visible */
+	if (gtk_window_is_active(window))
+		return;
+
+	name = g_intern_string(pspec->name);
+	value = g_new0(GValue, 1);
+	g_value_init(value, pspec->value_type);
+
+	if (name == g_intern_string("embedded"))
+	{
+		g_object_get_property(G_OBJECT(sicon), name, value);
+		/* if the icon is not embedded anymore, we display the main window otherwise
+		 * it will be lost */
+		if (! g_value_get_boolean(value))
+		{
+			gtk_window_present(window);
+		}
+	}
+}
+
+
 static void gigolo_window_settings_notify_cb(GigoloSettings *settings, GParamSpec *pspec, GigoloWindow *window)
 {
 	const gchar *name;
@@ -1329,7 +1355,7 @@ static void create_icon_view(GigoloWindow *window)
 			"icon-name", GIGOLO_WINDOW_COL_ICON_NAME);
 
 	renderer = gtk_cell_renderer_text_new();
-	g_object_set(renderer, "xalign", 0.5, "yalign", 1.0, NULL);
+	g_object_set(renderer, "xalign", 0.5, "yalign", 0.0, NULL);
 	gtk_cell_layout_pack_end(GTK_CELL_LAYOUT(priv->iconview), renderer, TRUE);
 	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(priv->iconview), renderer,
 		"text", GIGOLO_WINDOW_COL_NAME, NULL);
@@ -1404,6 +1430,10 @@ static void gigolo_window_init(GigoloWindow *window)
 	priv->action_open = gtk_action_group_get_action(priv->action_group, "Open");
 	priv->action_copyuri = gtk_action_group_get_action(priv->action_group, "CopyURI");
 
+	g_object_set(priv->action_bookmarks, "is-important", TRUE, NULL);
+	g_object_set(gtk_action_group_get_action(priv->action_group, "EditBookmarks"),
+		"is-important", TRUE, NULL);
+
 	/* Panel */
 	panel_pane = gtk_hpaned_new();
 	gtk_paned_set_position(GTK_PANED(panel_pane), 200);
@@ -1437,6 +1467,7 @@ static void gigolo_window_init(GigoloWindow *window)
 	gigolo_status_icon_set_tooltip_text(priv->systray_icon, _("Gigolo"));
 	g_signal_connect(priv->systray_icon, "activate", G_CALLBACK(systray_icon_activate_cb), window);
 	g_signal_connect(priv->systray_icon, "popup-menu", G_CALLBACK(systray_icon_popup_menu_cb), window);
+	g_signal_connect(priv->systray_icon, "notify", G_CALLBACK(gigolo_window_systray_notify_cb), window);
 
 	g_object_unref(ui_manager);
 }
